BBC - Home
Description: The best of the BBC, with the latest news and sport headlines, weather, TV & radio highlights and much more from across the whole of BBC Online.

# BBC Homepage

- Live.

  Explosion outside Kabul airport

  Attribution
    World
- Live.

  Latest as England extend first-innings lead to over 150 against India

  Attribution
    Cricket

- 'I'm living proof you can follow your passion and make money'

  Attribution
    BBC Radio 1Xtra

## More top stories

Sports Direct owner's new boss offered £100m bonus

Attribution
  Business

Food firm in 'drastic' action amid driver shortage

Attribution
  Business
Comments
  1624

Leopard attacks model in German photoshoot

Attribution
  Europe

## Coronavirus pandemic

Presenter's death due to Covid vaccine complications

Attribution
  Tyne & Wear

Should we worry about waning immunity and rising cases?

Attribution
  Health
Comments
  1337

Covid jabs available at Reading and Leeds

Attribution
  Berkshire
Comments
  31

## News headlines

Live.

Explosion outside Kabul airport

Attribution
  World

Majority of eligible people evacuated from Kabul - PM

Attribution
  UK

Presenter's death due to Covid vaccine complications

Attribution
  Tyne & Wear

## Sport headlines

England squad announcement, transfer latest and Premier League news conferences

Attribution
  Football

Ex-England captain Dexter dies aged 86

Attribution
  Cricket
Comments
  287

All you need to know about the Champions League draw

Attribution
  European Football

## Paralympics

Pearson leads GB gold rush on day two

Attribution
  Disability Sport

‘I’ve been in self-isolation for three years’

Attribution
  Disability Sport

'I didn't know about Para-sport until I was 22 and saw it on TV'

Attribution
  Disability Sport

## Around the UK

GPs warn of rush back to face-to-face appointments

Attribution
  Scotland
Comments
  256

Staff shortages hitting supermarket shelves

Attribution
  Wales
Comments
  317

Swann apologises for long hospital waiting lists

Attribution
  Northern Ireland
Comments
  124

## 3 things we love today

- These staycation pictures are the most British thing ever

  Attribution
    In Pictures

- 'The most memorable moments of my 45-year BBC career'

  Attribution
    Sport

- Have your say in this year's Countryfile calendar competition

  Attribution
    BBC One

Herstory

## 'I didn't know if drag was a possibility for a woman'

Victoria Scone is breaking boundaries as the first female queen on RuPaul's Drag Race UK
Herstory

## Entertainment news

Abba tease big announcement ahead of new music

Attribution
  Entertainment & Arts

Can Frozen stage musical recreate the film's magic?

Attribution
  Entertainment & Arts

Letitia Wright injured in Black Panther accident

Attribution
  Entertainment & Arts

## Talked about TV

How to follow the must-see sets across Reading and Leeds Festival

Attribution
  BBC Music

Ruth Jones and Rob Brydon reunite in one-off sitcom

Attribution
  Wales

'As it's set on a submarine, the tension is already written into it'

Attribution
  BBC Media Centre

## Society

'Deferral packages are unfair to current students'

Attribution
  Newsbeat

Insect decline linked to light pollution

Attribution
  Science & Environment
Comments
  94

Police warning after dad called police to say daughter stuck in coat

Attribution
  England

## Real-life stories

The SAS soldier watched by millions on live television

Attribution
  Tayside and Central Scotland

'My husband refused a divorce for nine years'

Attribution
  UK

Veteran in tears at chance reunion with pilot

Attribution
  UK

## You might have missed

'I thought it was a toy or seaweed, then it felt like time stood still'

Attribution
  England

Club completes challenge to bag all Munros in one day

Attribution
  Edinburgh, Fife & East Scotland

Nirvana sued by the baby from Nevermind cover

Attribution
  Entertainment & Arts

## Food

Easy pasta recipes ready in less than 30 minutes

Attribution
  BBC Food

Brilliant sandwich ideas for lunch or dinner

Attribution
  BBC Food

From crumble to chutney: Plenty of plum-packed recipes

Attribution
  BBC Food

## Lifestyle

- Celebrate World Burger Day with the weirdest burgers around

  Attribution
    Newsround

- Hidden immunity benefits of a plant-based diet

  Attribution
    BBC Food

- $20,000 puffy Dorito: The most expensive foods in the world

  Attribution
    News

## This week in sport

Five outrageous Premier League goal celebrations. VideoFive outrageous Premier League goal celebrations

Attribution
  Football

Australian Open plans bio-secure bubble

Attribution
  Tennis

Fifa writes to PM over red-list countries

Attribution
  Football

## Behind the headlines

Helping define rock 'n' roll: Charlie Watts' life in pictures

Attribution
  Entertainment & Arts

'Those few hours were the most dangerous of my life'

Attribution
  Asia

OnlyFans suspends policy change after backlash

Attribution
  Technology

## Time well spent

- Gossip Girl is back - and no one's secrets are safe. IPlayer-VideoGossip Girl is back - and no one's secrets are safe

  Attribution
    BBC One

- The story of one of America's most corrupt police units. AudioThe story of one of America's most corrupt police units

  Attribution
    BBC World Service

- The people who lost everything with one tweet. AudioThe people who lost everything with one tweet

  Attribution
    BBC Radio 4

## National Lottery draws

See the latest results, including Lotto, EuroMillions, Set for Life and Thunderball

RESULTS